<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="zh_CN">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About</source>
        <translation type="obsolete">关于</translation>
    </message>
    <message>
        <source>Authors</source>
        <translation>作者</translation>
    </message>
    <message>
        <source>License</source>
        <translation>许可证</translation>
    </message>
    <message>
        <source>Lightweight WebKit-based web browser</source>
        <translation>轻快的浏览器-基于Webkit</translation>
    </message>
    <message>
        <source>&lt;a href=&quot;http://arora-browser.org&quot;&gt;http://arora-browser.org&lt;/a&gt;</source>
        <translation></translation>
    </message>
    <message>
        <source>Close</source>
        <translation>关闭</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message utf8="true">
        <source>&lt;!DOCTYPE HTML PUBLIC &quot;-//W3C//DTD HTML 4.0//EN&quot; &quot;http://www.w3.org/TR/REC-html40/strict.dtd&quot;&gt;
&lt;html&gt;&lt;head&gt;&lt;meta name=&quot;qrichtext&quot; content=&quot;1&quot; /&gt;&lt;style type=&quot;text/css&quot;&gt;
p, li { white-space: pre-wrap; }
&lt;/style&gt;&lt;/head&gt;&lt;body style=&quot;font-size:9pt;&quot;&gt;
&lt;p style=&quot; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;&quot;&gt;Copyright © 2007-2009 Benjamin C. Meyer &amp;lt;&lt;a href=&quot;mailto:ben@meyerhome.net&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0057ae;&quot;&gt;ben@meyerhome.net&lt;/span&gt;&lt;/a&gt;&amp;gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>WebKit version: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AcceptLanguage</name>
    <message>
        <source>Languages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Languages: in order of preference:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move &amp;Up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Move &amp;Down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation type="unfinished">移除(&amp;R)</translation>
    </message>
    <message>
        <source>Add...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdBlockBlockedNetworkReply</name>
    <message>
        <source>Blocked by AdBlockRule: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdBlockDialog</name>
    <message>
        <source>Add Custom Rule</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Learn more about writing rules...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Update Subscription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse Subscriptions...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove Subscription</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AdBlock Configuration</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable AdBlock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Action</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdBlockManager</name>
    <message>
        <source>Custom Rules</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AdBlockModel</name>
    <message>
        <source>Rule</source>
        <translation type="unfinished">规则</translation>
    </message>
</context>
<context>
    <name>AdBlockSchemeAccessHandler</name>
    <message>
        <source>Subscribe?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Subscribe to this AdBlock subscription?
%1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddBookmarkDialog</name>
    <message>
        <source>Add Bookmark</source>
        <translation>添加书签</translation>
    </message>
    <message>
        <source>Type a name for the bookmark, and choose where to keep it.</source>
        <translation>请输入书签名，并选择保存位置</translation>
    </message>
    <message>
        <source>Url</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title</source>
        <translation type="unfinished">标题</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation type="unfinished">添加文件夹</translation>
    </message>
</context>
<context>
    <name>AutoFillDialog</name>
    <message>
        <source>Form Passwords</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AutoFillManager</name>
    <message>
        <source>&lt;b&gt;Would you like to save this password?&lt;/b&gt;&lt;br&gt;         To review passwords you have saved and remove them, open the AutoFill pane of preferences.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Never for this site</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not now</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AutoFillModel</name>
    <message>
        <source>WebSite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User Name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BookmarksDialog</name>
    <message>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <source>Open in New Tab</source>
        <translation>在新标签页中打开</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>新建文件夹</translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation>书签</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>移除(&amp;R)</translation>
    </message>
    <message>
        <source>Add Folder</source>
        <translation>添加文件夹</translation>
    </message>
    <message>
        <source>Edit Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Address</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BookmarksManager</name>
    <message>
        <source>Error when loading bookmarks on line %1, column %2:
%3</source>
        <translation>在行%1，列%2:
%3导入书签时出错</translation>
    </message>
    <message>
        <source>Toolbar Bookmarks</source>
        <translation>工具栏书签</translation>
    </message>
    <message>
        <source>Menu</source>
        <translation>菜单</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>打开文件</translation>
    </message>
    <message>
        <source>Imported %1</source>
        <translation>导入的%1</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>保存文件</translation>
    </message>
    <message>
        <source>%1 Bookmarks.xbel</source>
        <translation></translation>
    </message>
    <message>
        <source>Export error</source>
        <translation>导出错误</translation>
    </message>
    <message>
        <source>error saving bookmarks</source>
        <translation>保存书签出错</translation>
    </message>
    <message>
        <source>Remove Bookmark</source>
        <translation>移除书签</translation>
    </message>
    <message>
        <source>Insert Bookmark</source>
        <translation>插入书签</translation>
    </message>
    <message>
        <source>Name Change</source>
        <translation type="obsolete">名字变更</translation>
    </message>
    <message>
        <source>Address Change</source>
        <translation type="obsolete">地址变更</translation>
    </message>
    <message>
        <source>Bookmarks Bar</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bookmarks Menu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name Change</source>
        <comment>Undo bookmark title change</comment>
        <translation type="unfinished">名字变更</translation>
    </message>
    <message>
        <source>Address Change</source>
        <comment>Undo bookmark url change</comment>
        <translation type="unfinished">地址变更</translation>
    </message>
    <message>
        <source>XBEL bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>HTML Netscape bookmarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>htmlToXBel tool required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>htmlToXBel tool, which is shipped with Arora and is needed to import HTML bookmarks, is not installed or not available in the search paths.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading Bookmark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error when loading HTML bookmarks: %1
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BookmarksMenu</name>
    <message>
        <source>Open in Tabs</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BookmarksModel</name>
    <message>
        <source>Title</source>
        <translation>标题</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>地址</translation>
    </message>
</context>
<context>
    <name>BookmarksToolBar</name>
    <message>
        <source>Bookmark</source>
        <translation type="obsolete">书签</translation>
    </message>
    <message>
        <source>Open</source>
        <translation type="unfinished">打开</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation type="unfinished">在新标签页中打开(&amp;T)</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation type="unfinished">添加标签...</translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bookmarks</source>
        <translation type="obsolete">书签</translation>
    </message>
</context>
<context>
    <name>BrowserApplication</name>
    <message>
        <source> (Change: %1 %2)</source>
        <translation type="obsolete">(变更： %1 %2)</translation>
    </message>
    <message>
        <source>There are %1 windows and %2 tabs open
Do you want to quit anyway?</source>
        <translation>有%1个窗口和%2个标签为打开状态
仍旧确认退出吗？</translation>
    </message>
    <message>
        <source>Restore failed</source>
        <translation>恢复失败</translation>
    </message>
    <message>
        <source>The saved session will not be restored because Arora crashed while trying to restore this session.</source>
        <translation type="obsolete">保存的会话不会恢复，因为Arora在尝试恢复该会话时已崩溃。</translation>
    </message>
    <message>
        <source>Arora crashed while trying to restore this session.  Should I try again?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BrowserMainWindow</name>
    <message>
        <source>&amp;File</source>
        <translation>文件(&amp;F)</translation>
    </message>
    <message>
        <source>&amp;New Window</source>
        <translation>新窗口(&amp;N)</translation>
    </message>
    <message>
        <source>&amp;Open File...</source>
        <translation>打开文件(&amp;O)...</translation>
    </message>
    <message>
        <source>Open &amp;Location...</source>
        <translation>打开位置(&amp;L)...</translation>
    </message>
    <message>
        <source>&amp;Save As...</source>
        <translation>另存为(&amp;S)...</translation>
    </message>
    <message>
        <source>&amp;Import Bookmarks...</source>
        <translation>导入书签(&amp;I)...</translation>
    </message>
    <message>
        <source>&amp;Export Bookmarks...</source>
        <translation>导出书签(&amp;E)...</translation>
    </message>
    <message>
        <source>P&amp;rint Preview...</source>
        <translation>打印预览(&amp;P)...</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>打印(&amp;P)...</translation>
    </message>
    <message>
        <source>Private &amp;Browsing...</source>
        <translation>隐私浏览(&amp;B)...</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>退出(&amp;Q)</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>编辑(&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>撤销(&amp;U)</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>重做(&amp;R)</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>剪切(&amp;t)</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>复制(&amp;C)</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>粘帖(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>查找(&amp;F)</translation>
    </message>
    <message>
        <source>Find Nex&amp;t</source>
        <translation>查找下一个(&amp;t)</translation>
    </message>
    <message>
        <source>Find P&amp;revious</source>
        <translation>查找前一个(&amp;r)</translation>
    </message>
    <message>
        <source>Prefere&amp;nces...</source>
        <translation type="obsolete">选项(&amp;r)...</translation>
    </message>
    <message>
        <source>Ctrl+,</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>查看(&amp;V)</translation>
    </message>
    <message>
        <source>Show Menu Bar</source>
        <translation>显示菜单栏</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation></translation>
    </message>
    <message>
        <source>Ctrl+/</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Stop</source>
        <translation>停止(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Reload Page</source>
        <translation>重新加载页面(&amp;R)</translation>
    </message>
    <message>
        <source>Make Text &amp;Bigger</source>
        <translation type="obsolete">字体放大(&amp;B)</translation>
    </message>
    <message>
        <source>Make Text &amp;Normal</source>
        <translation type="obsolete">普通字体(&amp;N)</translation>
    </message>
    <message>
        <source>Make Text &amp;Smaller</source>
        <translation type="obsolete">字体缩小(&amp;S)</translation>
    </message>
    <message>
        <source>Page S&amp;ource</source>
        <translation>页面源码(&amp;o)</translation>
    </message>
    <message>
        <source>Ctrl+Alt+U</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Full Screen</source>
        <translation>全屏(&amp;F)</translation>
    </message>
    <message>
        <source>Hi&amp;story</source>
        <translation>历史(&amp;s)</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>后退</translation>
    </message>
    <message>
        <source>Forward</source>
        <translation>前进</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>主页</translation>
    </message>
    <message>
        <source>Restore Last Session</source>
        <translation>恢复最后一次会话</translation>
    </message>
    <message>
        <source>&amp;Bookmarks</source>
        <translation>标签(&amp;B)</translation>
    </message>
    <message>
        <source>Manage Bookmarks...</source>
        <translation type="obsolete">管理标签...</translation>
    </message>
    <message>
        <source>Add Bookmark...</source>
        <translation>添加标签...</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>窗口(&amp;W)</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>工具(&amp;T)</translation>
    </message>
    <message>
        <source>Web &amp;Search</source>
        <translation>Web搜索(&amp;S)</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <comment>Web Search</comment>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Clear Private Data</source>
        <translation>清除隐私数据(&amp;C)</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Delete</source>
        <comment>Clear Private Data</comment>
        <translation></translation>
    </message>
    <message>
        <source>Enable Web &amp;Inspector</source>
        <translation>允许Web &amp;Inspector</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>帮助(&amp;H)</translation>
    </message>
    <message>
        <source>Switch application language </source>
        <translation>切换应用程序语言</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>关于&amp;Qt</translation>
    </message>
    <message>
        <source>About &amp;Arora</source>
        <translation type="obsolete">关于&amp;Arora</translation>
    </message>
    <message>
        <source>Navigation</source>
        <translation>导航</translation>
    </message>
    <message>
        <source>Show Status Bar</source>
        <translation>显示状态栏</translation>
    </message>
    <message>
        <source>Hide Status Bar</source>
        <translation>隐藏状态栏</translation>
    </message>
    <message>
        <source>Show Toolbar</source>
        <translation>显示工具栏</translation>
    </message>
    <message>
        <source>Hide Toolbar</source>
        <translation>隐藏工具栏</translation>
    </message>
    <message>
        <source>Show Bookmarks Bar</source>
        <translation>显示标签栏</translation>
    </message>
    <message>
        <source>Hide Bookmarks Bar</source>
        <translation>隐藏标签栏</translation>
    </message>
    <message>
        <source>%1 - Arora</source>
        <comment>Page title and Browser name</comment>
        <translation>%1 - Arora</translation>
    </message>
    <message>
        <source>Open Web Resource</source>
        <translation>打开Web资源</translation>
    </message>
    <message>
        <source>Web Resources (*.html *.htm *.svg *.png *.gif *.svgz);;All files (*.*)</source>
        <translation>Web资源 (*.html *.htm *.svg *.png *.gif *.svgz);;所有文件 (*.*)</translation>
    </message>
    <message>
        <source>Print Document</source>
        <translation>打印文档</translation>
    </message>
    <message>
        <source>Are you sure you want to turn on private browsing?</source>
        <translation>是否确认打开隐私浏览？</translation>
    </message>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;When private browsing is turned on, some actions concerning your privacy will be disabled:&lt;ul&gt;&lt;li&gt; Webpages are not added to the history.&lt;/li&gt;&lt;li&gt; Items are automatically removed from the Downloads window.&lt;/li&gt;&lt;li&gt; New cookies are not stored, current cookies can&apos;t be accessed.&lt;/li&gt;&lt;li&gt; Site icons won&apos;t be stored, session won&apos;t be saved.&lt;/li&gt;&lt;li&gt; Searches are not addded to the pop-up menu in the search box.&lt;/li&gt;&lt;/ul&gt;Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="obsolete">&lt;b&gt;%1&lt;/b&gt;&lt;br&gt;&lt;br&gt;当开启隐私浏览时，关于你的某些隐私动作不会被记录：&lt;ul&gt;&lt;li&gt; 页面不会被添加到历史中。&lt;/li&gt;&lt;li&gt;下载项会自动从下载窗口移除。 &lt;/li&gt;&lt;li&gt; 新的cookies不会被存储，当前的cookies也不会被访问。&lt;/li&gt;&lt;li&gt;站点图标不会被存储，会话也不会被保存。 &lt;/li&gt;&lt;li&gt;搜索动作不会被添加到搜索框的弹出菜单中。&lt;/li&gt;&lt;/ul&gt;在关闭窗口之前，你可以一直通过点击后退和前进按钮来浏览已打开过的页面。</translation>
    </message>
    <message>
        <source>Are you sure you want to close the window?  There are %1 tabs open</source>
        <translation>是否确认关闭窗口？还有%1个标签打开着</translation>
    </message>
    <message>
        <source>Web Inspector</source>
        <translation></translation>
    </message>
    <message>
        <source>The web inspector will only work correctly for pages that were loaded after enabling.
Do you want to reload all pages?</source>
        <translation>web inspector只在页面被允许且被加载后才能正常运行。
希望重新加载所有页面吗？</translation>
    </message>
    <message>
        <source>Stop loading the current page</source>
        <translation>停止加载当前页面</translation>
    </message>
    <message>
        <source>Reload the current page</source>
        <translation>重新加载当前页面</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>下载</translation>
    </message>
    <message>
        <source>Close Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Zoom &amp;Text Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Show All Bookmarks...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Folder...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About &amp;%1</source>
        <comment>About Browser</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Y</source>
        <comment>Download Manager</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="unfinished">缺省</translation>
    </message>
    <message>
        <source>Text Encoding</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+Ctrl+B</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Options...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Configure Search Engines...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Ad Block...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When private browsing is turned on, some actions concerning your privacy will be disabled:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Webpages are not added to the history.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Items are automatically removed from the Downloads window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New cookies are not stored, current cookies can&apos;t be accessed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Site icons won&apos;t be stored.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Session won&apos;t be saved.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Searches are not added to the pop-up menu in the search box.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No new network cache is written to disk.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Until you close the window, you can still click the Back and Forward buttons to return to the webpages you have opened.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Private Browsing</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClearButton</name>
    <message>
        <source>Clear</source>
        <translation>清除</translation>
    </message>
</context>
<context>
    <name>ClearPrivateData</name>
    <message>
        <source>Clear Private Data</source>
        <translation>清除隐私数据</translation>
    </message>
    <message>
        <source>Clear the following items:</source>
        <translation>清除以下项：</translation>
    </message>
    <message>
        <source>&amp;Browsing History</source>
        <translation>浏览历史(&amp;B)</translation>
    </message>
    <message>
        <source>&amp;Download History</source>
        <translation>下载历史(&amp;D)</translation>
    </message>
    <message>
        <source>&amp;Search History</source>
        <translation>搜索历史(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Cookies</source>
        <translation></translation>
    </message>
    <message>
        <source>C&amp;ached Web Pages</source>
        <translation>缓存的页面(&amp;a)</translation>
    </message>
    <message>
        <source>Website &amp;Icons</source>
        <translation>网站图标(&amp;I)</translation>
    </message>
    <message>
        <source>Clear &amp;Private Data</source>
        <translation>清除隐私数据(&amp;P)</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>取消(&amp;C)</translation>
    </message>
</context>
<context>
    <name>ClickToFlash</name>
    <message>
        <source>Load</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add %1 to Whitelist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remove from Whitelist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load Flash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClickToFlashSettings</name>
    <message>
        <source>Whitelist sites</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CookieExceptionsModel</name>
    <message>
        <source>Website</source>
        <translation>网站</translation>
    </message>
    <message>
        <source>Rule</source>
        <translation>规则</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>允许</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>阻挡</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>会话中允许</translation>
    </message>
</context>
<context>
    <name>CookieModel</name>
    <message>
        <source>Website</source>
        <translation>网站</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>名字</translation>
    </message>
    <message>
        <source>Path</source>
        <translation>路径</translation>
    </message>
    <message>
        <source>Secure</source>
        <translation>安全</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>失效</translation>
    </message>
    <message>
        <source>Contents</source>
        <translation>内容</translation>
    </message>
    <message>
        <source>true</source>
        <translation></translation>
    </message>
    <message>
        <source>false</source>
        <translation></translation>
    </message>
    <message>
        <source>Session cookie</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CookiesDialog</name>
    <message>
        <source>Cookies</source>
        <translation></translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>移除(&amp;R)</translation>
    </message>
    <message>
        <source>Remove &amp;All Cookies</source>
        <translation>移除所有Cookies(&amp;A)</translation>
    </message>
    <message>
        <source>Add &amp;Rule</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CookiesExceptionsDialog</name>
    <message>
        <source>Cookie Exceptions</source>
        <translation>Cookie例外</translation>
    </message>
    <message>
        <source>New Exception</source>
        <translation>新建例外</translation>
    </message>
    <message>
        <source>Domain:</source>
        <translation>域：</translation>
    </message>
    <message>
        <source>Block</source>
        <translation>阻挡</translation>
    </message>
    <message>
        <source>Allow For Session</source>
        <translation>会话中允许</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>允许</translation>
    </message>
    <message>
        <source>Exceptions</source>
        <translation>例外</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>移除(&amp;R)</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>移除所有(&amp;A)</translation>
    </message>
</context>
<context>
    <name>DownloadDialog</name>
    <message>
        <source>Downloads</source>
        <translation>下载</translation>
    </message>
    <message>
        <source>Clean up</source>
        <translation>清除</translation>
    </message>
    <message>
        <source>0 Items</source>
        <translation>0项</translation>
    </message>
</context>
<context>
    <name>DownloadItem</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">表单</translation>
    </message>
    <message>
        <source>Ico</source>
        <translation></translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>文件名</translation>
    </message>
    <message>
        <source>Try Again</source>
        <translation>重新尝试</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>停止</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <source>Save File</source>
        <translation>保存文件</translation>
    </message>
    <message>
        <source>Download canceled: %1</source>
        <translation>下载取消： %1</translation>
    </message>
    <message>
        <source>Error opening output file: %1</source>
        <translation>打开输出文件出错： %1</translation>
    </message>
    <message>
        <source>Error saving: %1</source>
        <translation>保存出错： %1</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>网络出错： %1</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation type="obsolete">秒</translation>
    </message>
    <message numerus="yes">
        <source>- %n minutes remaining</source>
        <translation type="obsolete">
            <numerusform>- 还有 %n 分钟</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>- %n seconds remaining</source>
        <translation type="obsolete">
            <numerusform>- 还有 %n 秒</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) %4</source>
        <translation type="obsolete">%1 of %2 (%3/秒) %4</translation>
    </message>
    <message>
        <source>?</source>
        <translation></translation>
    </message>
    <message>
        <source>%1 of %2 - Stopped</source>
        <translation>%1 of %2 - 停止</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation type="obsolete">字节</translation>
    </message>
    <message>
        <source>%1 of %2 (%3/sec) - %4</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Download directory (%1) couldn&apos;t be created.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DownloadManager</name>
    <message numerus="yes">
        <source>%n Download(s)</source>
        <translation>
            <numerusform>%n 下载</numerusform>
        </translation>
    </message>
    <message>
        <source>There are %1 downloads in progress
Do you want to quit anyway?</source>
        <translation type="unfinished"></translation>
    </message>
    <message numerus="yes">
        <source>%n minutes remaining</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n seconds remaining</source>
        <translation type="unfinished">
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>bytes</source>
        <translation type="unfinished">字节</translation>
    </message>
    <message>
        <source>kB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FileAccessReply</name>
    <message>
        <source>No Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error opening: %1: No such file or directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to read %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Contents of %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HistoryDialog</name>
    <message>
        <source>Open</source>
        <translation>打开</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>复制</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>删除</translation>
    </message>
    <message>
        <source>History</source>
        <translation>历史</translation>
    </message>
    <message>
        <source>&amp;Remove</source>
        <translation>移除(&amp;R)</translation>
    </message>
    <message>
        <source>Remove &amp;All</source>
        <translation>移除所有(&amp;A)</translation>
    </message>
</context>
<context>
    <name>HistoryMenu</name>
    <message>
        <source>Show All History</source>
        <translation>显示所有历史</translation>
    </message>
    <message>
        <source>Clear History...</source>
        <translation>清除历史...</translation>
    </message>
    <message>
        <source>Clear History</source>
        <translation>清除历史</translation>
    </message>
    <message>
        <source>Do you want to clear the history?</source>
        <translation>希望清除历史吗？</translation>
    </message>
</context>
<context>
    <name>HistoryModel</name>
    <message>
        <source>Title</source>
        <translation>标题</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>地址</translation>
    </message>
</context>
<context>
    <name>HistoryTreeModel</name>
    <message>
        <source>Earlier Today</source>
        <translation>早些时候</translation>
    </message>
    <message numerus="yes">
        <source>%n item(s)</source>
        <translation>
            <numerusform>%n 项</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>JavaScriptAroraObject</name>
    <message>
        <source>Welcome to Arora!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arora Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search results provided by</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>About Arora</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LanguageManager</name>
    <message>
        <source>Default</source>
        <translation type="obsolete">缺省</translation>
    </message>
    <message>
        <source>Choose language</source>
        <translation>选择语言</translation>
    </message>
    <message>
        <source>&lt;p&gt;You can run with a different language than&lt;br&gt;the operating system default.&lt;/p&gt;&lt;p&gt;Please choose the language which should be used&lt;/p&gt;</source>
        <translation>&lt;p&gt;你可以运行在其它语言环境下&lt;br&gt;而不采用操作系统所缺省的语言环境&lt;/p&gt;&lt;p&gt;请选择应该使用的语言环境&lt;/p&gt;</translation>
    </message>
    <message>
        <source>No translation files are installed at %1.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetworkAccessManager</name>
    <message>
        <source>&lt;qt&gt;Enter username and password for &quot;%1&quot; at %2&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;为 &quot;%1&quot; 在 %2 输入用户名和密码&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>&lt;qt&gt;Connect to proxy &quot;%1&quot; using:&lt;/qt&gt;</source>
        <translation>&lt;qt&gt;连接到代理 &quot;%1&quot; 使用：&lt;/qt&gt;</translation>
    </message>
    <message>
        <source>SSL Errors:

%1

%2

Do you want to ignore these errors?</source>
        <translation type="obsolete">SSL 错误：%1%2希望忽略该错误吗？</translation>
    </message>
    <message>
        <source>Do you want to accept all these certificates?</source>
        <translation type="obsolete">确认接受所有证书吗？</translation>
    </message>
    <message>
        <source> - SSL Errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;qt&gt;SSL Errors:&lt;br/&gt;&lt;br/&gt;for: &lt;tt&gt;%1&lt;/tt&gt;&lt;ul&gt;&lt;li&gt;%2&lt;/li&gt;&lt;/ul&gt;

Do you want to ignore these errors?&lt;/qt&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;qt&gt;Certificates:&lt;br/&gt;%1&lt;br/&gt;Do you want to accept all these certificates?&lt;/qt&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Issuer: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Not valid before: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Valid until: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alternate Names:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NetworkMonitor</name>
    <message>
        <source>Name</source>
        <translation type="obsolete">名字</translation>
    </message>
</context>
<context>
    <name>NetworkMonitorDialog</name>
    <message>
        <source>&amp;Remove</source>
        <translation type="obsolete">移除(&amp;R)</translation>
    </message>
</context>
<context>
    <name>OpenSearchDialog</name>
    <message>
        <source>Open File</source>
        <translation type="unfinished">打开文件</translation>
    </message>
    <message>
        <source>OpenSearch</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is not a valid OpenSearch 1.1 description or is already on your list.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must have at least one search engine in here.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OpenSearch Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Restore Defaults</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSearchEngineModel</name>
    <message>
        <source>&lt;strong&gt;Description:&lt;/strong&gt; %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&lt;strong&gt;Provides contextual suggestions&lt;/strong&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Comma-separated list of keywords that may be entered in the location barfollowed by search terms to search with this engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished">名字</translation>
    </message>
    <message>
        <source>Keywords</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenSearchManager</name>
    <message>
        <source>Do you want to add the following engine to your list of search engines?&lt;br /&gt;&lt;br /&gt;Name: %1&lt;br /&gt;Searches on: %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PasswordDialog</name>
    <message>
        <source>Authentication Required</source>
        <translation>需要验证</translation>
    </message>
    <message>
        <source>DUMMY ICON</source>
        <translation></translation>
    </message>
    <message>
        <source>INTRO TEXT DUMMY</source>
        <translation></translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>用户名：</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>密码：</translation>
    </message>
</context>
<context>
    <name>PlainTextEditSearch</name>
    <message>
        <source>Not Found</source>
        <translation>未找到</translation>
    </message>
</context>
<context>
    <name>ProxyDialog</name>
    <message>
        <source>Proxy Authentication</source>
        <translation>代理验证</translation>
    </message>
    <message>
        <source>Connect to proxy</source>
        <translation>连接到代理</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>用户名：</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>密码：</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The file is not an XBEL version 1.0 file.</source>
        <translation>该文件不是版本为1.0的XBEL文件</translation>
    </message>
    <message>
        <source>Unknown title</source>
        <translation>未知文件</translation>
    </message>
    <message>
        <source>The file is not an OpenSearch 1.1 file.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RequestModel</name>
    <message>
        <source>Address</source>
        <translation type="obsolete">地址</translation>
    </message>
</context>
<context>
    <name>SearchBanner</name>
    <message>
        <source>Form</source>
        <translation type="obsolete">表单</translation>
    </message>
    <message>
        <source>TextLabel</source>
        <translation type="obsolete">文本标签</translation>
    </message>
    <message>
        <source>Done</source>
        <translation>完成</translation>
    </message>
    <message>
        <source>Highlight All</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Preferences</source>
        <translation>选项</translation>
    </message>
    <message>
        <source>General</source>
        <translation>常规</translation>
    </message>
    <message>
        <source>On startup:</source>
        <translation>启动时：</translation>
    </message>
    <message>
        <source>Show my home page</source>
        <translation>显示我的主页</translation>
    </message>
    <message>
        <source>Show a blank page</source>
        <translation>显示空白页</translation>
    </message>
    <message>
        <source>Restore windows and tabs from last time</source>
        <translation>恢复最后一次的窗口和标签</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>主页：</translation>
    </message>
    <message>
        <source>Set to current page</source>
        <translation>设置为当前页面</translation>
    </message>
    <message>
        <source>Remove history items:</source>
        <translation>移除历史项：</translation>
    </message>
    <message>
        <source>After one day</source>
        <translation>一天后</translation>
    </message>
    <message>
        <source>After one week</source>
        <translation>一周后</translation>
    </message>
    <message>
        <source>After two weeks</source>
        <translation>两周后</translation>
    </message>
    <message>
        <source>After one month</source>
        <translation>一个月后</translation>
    </message>
    <message>
        <source>After one year</source>
        <translation>一年后</translation>
    </message>
    <message>
        <source>Manually</source>
        <translation>手工</translation>
    </message>
    <message>
        <source>On application exit</source>
        <translation>应用退出</translation>
    </message>
    <message>
        <source>Open links from applications:</source>
        <translation>从应用程序打开链接：</translation>
    </message>
    <message>
        <source>In a tab in the current window</source>
        <translation type="obsolete">在当前窗口的标签中</translation>
    </message>
    <message>
        <source>In a new window</source>
        <translation>在新窗口中</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>下载</translation>
    </message>
    <message>
        <source>Ask for a destination each time</source>
        <translation>每次均询问目的地</translation>
    </message>
    <message>
        <source>Use this destination:</source>
        <translation>使用该目的地：</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>外观</translation>
    </message>
    <message>
        <source>Standard font:</source>
        <translation>标准字体：</translation>
    </message>
    <message>
        <source>Select...</source>
        <translation>选择...</translation>
    </message>
    <message>
        <source>Fixed-width font:</source>
        <translation>定宽字体：</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>隐私</translation>
    </message>
    <message>
        <source>Web Content</source>
        <translation>Web内容</translation>
    </message>
    <message>
        <source>Enable Plugins</source>
        <translation>允许插件</translation>
    </message>
    <message>
        <source>Enable Javascript</source>
        <translation>允许Javascript</translation>
    </message>
    <message>
        <source>View Images</source>
        <translation>查看图片</translation>
    </message>
    <message>
        <source>Cookies</source>
        <translation></translation>
    </message>
    <message>
        <source>Accept Cookies:</source>
        <translation>接受Cookies：</translation>
    </message>
    <message>
        <source>Always</source>
        <translation>总是</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>从不</translation>
    </message>
    <message>
        <source>Only from sites you navigate to</source>
        <translation>只允许从浏览过的站点</translation>
    </message>
    <message>
        <source>Exceptions...</source>
        <translation>例外...</translation>
    </message>
    <message>
        <source>Keep Cookies Until:</source>
        <translation>保持Cookies直到：</translation>
    </message>
    <message>
        <source>They expire</source>
        <translation>它们失效</translation>
    </message>
    <message>
        <source>I exit the application</source>
        <translation>退出应用程序</translation>
    </message>
    <message>
        <source>At most 90 days</source>
        <translation>最多90天</translation>
    </message>
    <message>
        <source>Cookies...</source>
        <translation></translation>
    </message>
    <message>
        <source>Tabs</source>
        <translation>标签</translation>
    </message>
    <message>
        <source>Select tabs and windows as they are created</source>
        <translation>在标签和窗口被创建后选择它们</translation>
    </message>
    <message>
        <source>Confirm when closing multiple tabs</source>
        <translation type="obsolete">关闭多个标签时进行确认</translation>
    </message>
    <message>
        <source>Proxy</source>
        <translation>代理</translation>
    </message>
    <message>
        <source>Use proxy server</source>
        <translation>使用代理服务器</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>类型：</translation>
    </message>
    <message>
        <source>Socks5</source>
        <translation></translation>
    </message>
    <message>
        <source>Host name:</source>
        <translation>主机名：</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>端口：</translation>
    </message>
    <message>
        <source>User Name:</source>
        <translation>用户名：</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>密码：</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>高级</translation>
    </message>
    <message>
        <source>Style Sheet:</source>
        <translation>样式表：</translation>
    </message>
    <message>
        <source>Show only one close button instead of one for each tab</source>
        <translation>只显示一个关闭按钮，而不是在每个标签上都显示一个关闭按钮</translation>
    </message>
    <message>
        <source>Preferred languages for viewing webpages in:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Block Popup Windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Opening links</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Links that want to open in a new window:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In a new selected tab in the current window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In a new tab in the current window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In the current tab</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Http (Secure)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Http (Transparent)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use ClickToFlash on flash plugins</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter Tracking Cookies</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Confirm when closing multiple tabs or windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Quit the application when last tab is closed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable network cache</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum Size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source> MB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use the default search engine as fallback when the URL given by the user is invalid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose Directory...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>A cookie session ends:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>When I exit the application</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1 day</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>3 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>7 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>30 days</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AutoFill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>AutoFill web forms:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User names and passwords</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Browse...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Restart required</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The network cache configuration has changed. So that it can be taken into account, the browser has to be restarted.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose Directory</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose CSS File</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SourceViewer</name>
    <message>
        <source>Loading...</source>
        <translation>加载...</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>编辑(&amp;E)</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>查找(&amp;F)</translation>
    </message>
    <message>
        <source>Source of Page </source>
        <translation type="obsolete">页面源码</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation type="obsolete">查看(&amp;V)</translation>
    </message>
    <message>
        <source>&amp;Wrap lines</source>
        <translation type="obsolete">折叠行(&amp;W)</translation>
    </message>
    <message>
        <source>Source of Page %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TabBar</name>
    <message>
        <source>Show Tab Bar</source>
        <translation>显示标签栏</translation>
    </message>
    <message>
        <source>Hide Tab Bar</source>
        <translation>隐藏标签栏</translation>
    </message>
    <message>
        <source>New &amp;Tab</source>
        <translation type="obsolete">新标签页(&amp;T)</translation>
    </message>
    <message>
        <source>Duplicate Tab</source>
        <translation>复制标签</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>关闭标签(&amp;C)</translation>
    </message>
    <message>
        <source>Close &amp;Other Tabs</source>
        <translation>关闭其它标签(&amp;O)</translation>
    </message>
    <message>
        <source>Reload Tab</source>
        <translation>重新加载标签</translation>
    </message>
    <message>
        <source>Reload All Tabs</source>
        <translation>重新加载所有标签</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <source>New &amp;Tab</source>
        <translation>新标签页(&amp;T)</translation>
    </message>
    <message>
        <source>&amp;Close Tab</source>
        <translation>关闭标签(&amp;C)</translation>
    </message>
    <message>
        <source>Show Next Tab</source>
        <translation>显示下一个标签</translation>
    </message>
    <message>
        <source>Show Previous Tab</source>
        <translation>显示前一个标签</translation>
    </message>
    <message>
        <source>Recently Closed Tabs</source>
        <translation>最近关闭的标签</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>无标题</translation>
    </message>
    <message>
        <source>Do you really want to close this page?</source>
        <translation>确认关闭该页面？</translation>
    </message>
    <message>
        <source>You have modified this page and when closing it you would lose the modification.
Do you really want to close this page?
</source>
        <translation>页面已被修改，如果关闭，将丢失所有修改。确认关闭该页面？</translation>
    </message>
    <message>
        <source>Ctrl-]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl-[</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Saved Tabs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation type="unfinished">加载...</translation>
    </message>
    <message>
        <source>Loading %1% (%2 %3)...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Finished loading</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to load</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Bookmark All Tabs</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ToolbarSearch</name>
    <message>
        <source>No Recent Searches</source>
        <translation>无最近搜索</translation>
    </message>
    <message>
        <source>Recent Searches</source>
        <translation>最近搜索</translation>
    </message>
    <message>
        <source>Clear Recent Searches</source>
        <translation type="unfinished">清除最近搜索</translation>
    </message>
    <message>
        <source>Suggestions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebPage</name>
    <message>
        <source>Error loading page: %1</source>
        <translation>加载页面出错： %1</translation>
    </message>
    <message>
        <source>When connecting to: %1.</source>
        <translation>当连接至：%1</translation>
    </message>
    <message>
        <source>Check the address for errors such as &lt;b&gt;ww&lt;/b&gt;.trolltech.com instead of &lt;b&gt;www&lt;/b&gt;.trolltech.com.</source>
        <translation type="obsolete">检查地址是否错误，比如输入的是 &lt;b&gt;ww&lt;/b&gt;.trolltech.com 而不是 &lt;b&gt;www&lt;/b&gt;.trolltech.com.</translation>
    </message>
    <message>
        <source>If the address is correct, try to check the network connection.</source>
        <translation type="obsolete">如果地址正确，那么请检查网络是否连接。</translation>
    </message>
    <message>
        <source>If your computer or network is protected by a firewall or proxy, make sure that the browser is permitted to access the network.</source>
        <translation>如果计算机或网络被防火墙或代理所保护，请确认浏览器被允许访问网络。</translation>
    </message>
    <message>
        <source>Check the address for errors such as &lt;b&gt;ww&lt;/b&gt;.arora-browser.org instead of &lt;b&gt;www&lt;/b&gt;.arora-browser.org</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>If the address is correct, try checking the network connection.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Resending POST request</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>In order to display the site, the request along with all the data must be sent once again, which may lead to some unexpected behaviour of the site e.g. the same action might be performed once again. Do you want to continue anyway?</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebView</name>
    <message>
        <source>Open in New &amp;Window</source>
        <translation>在新窗口中打开(&amp;W)</translation>
    </message>
    <message>
        <source>Open in New &amp;Tab</source>
        <translation>在新标签页中打开(&amp;T)</translation>
    </message>
    <message>
        <source>Save Lin&amp;k</source>
        <translation>保存链接(&amp;k)</translation>
    </message>
    <message>
        <source>&amp;Bookmark This Link</source>
        <translation>添加该链接到书签(&amp;B)</translation>
    </message>
    <message>
        <source>&amp;Copy Link Location</source>
        <translation>复制链接地址(&amp;C)</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Window</source>
        <translation>在新窗口中打开图片(&amp;W)</translation>
    </message>
    <message>
        <source>Open Image in New &amp;Tab</source>
        <translation>在新标签页中打开图片(&amp;T)</translation>
    </message>
    <message>
        <source>&amp;Save Image</source>
        <translation>保存图片(&amp;S)</translation>
    </message>
    <message>
        <source>&amp;Copy Image</source>
        <translation>复制图片(&amp;C)</translation>
    </message>
    <message>
        <source>C&amp;opy Image Location</source>
        <translation>复制图片地址(&amp;o)</translation>
    </message>
    <message>
        <source>Loading...</source>
        <translation>加载...</translation>
    </message>
    <message>
        <source>Search with...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add to the toolbar search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Method not supported</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 method is not supported.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Choose the desired search engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Engine name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type in a name for the engine</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Block Image</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WebViewSearch</name>
    <message>
        <source>Not Found</source>
        <translation>未找到</translation>
    </message>
</context>
</TS>
